$scaling-factor:    0.9;

code {
  margin: 2px;
  padding: 2px;
}

code, pre {
  font-family: $mono-font;
  font-size: 1em * $scaling-factor;
}

pre {
  padding: $default-padding / 2;
  line-height: $line-height * $scaling-factor * 1.05;

  // This ensures that code blocks don't get blown up to big sizes
  // on iPhone displays.
  -webkit-text-size-adjust: 100%;
}

pre, code {
//  border: 1px solid $midtone-gray;
//  border-radius: 4px;
  overflow-x: auto;
  background-color: $light-grey;
}

code {
  padding: 1.5px 3px;
}

pre {
  border-radius: 0px;
  border: none;
  border-left: 5px solid $midtone-gray;
}

@import "pygments.scss";
