<!DOCTYPE html>
<html lang="{{ site.settings.language }}">

<head>
  <meta charset="utf-8" />
  <meta name="viewport" content="width=device-width, initial-scale=1.0" />
  {% if site.settings.author %}
    <meta name="author" content="{{ site.settings.author }}" />
  {% endif %}
  {% if site.settings.description %}
    <meta name="description" content="{{ site.settings.description }}" />
  {% endif %}

  {% include "base_head.html" %}

  <title>{% if metadata is defined and 'title' in metadata %}
      {{ metadata.title|striptags }} &mdash;
    {% elif title %}
      {{ title|striptags }} &mdash;
    {% endif %}{{ site.settings.name }}</title>
</title>
</head>

<body>
  <aside>
    <div id="aside_inner">
      {% include "base_header.html" %}
    </div>
  </aside>

  <main>
    <div id="main_inner">
      {% block content %}{% endblock %}
    </div>
  </main>

  <footer>
    <div id="footer_inner">
      {% include "base_footer.html" %}
    </div>
  </footer>
</body>

</html>
