body {
  margin:  0;
  padding: 0;
}

aside {
  background-color: $primary-color;
  background-size: auto 100%;

  &, a, a:visited, #subtitle {
    color: white;
  }
  a:hover {
    text-decoration: none;
  }
}

#brand {
  margin-top: 30px;
  margin-bottom: 20px;
  a {
    text-decoration: none;
    font-size: 1.5em;
  }
}

.dot_list {
  list-style-type: none;
  padding-left: 0px !important;

  // Ensure they all display in a line
  li {
    display: inline-block;
    &:not(:first-child)::before {
      content: " · ";
    }
  }
}

#aside_links ul {
  padding-top:    0px;
  padding-bottom: 0px;
  margin-bottom:  10px;
  li#search {
    float: right;
    &::before {
      content: "";
    }
    input {
      font: 12pt $main-font-family;
      margin-top: -3px;
    }
  }
}
