article {
  line-height: $line-height;
  padding-top:    3px;
  padding-bottom: 15px;
}

.post_title, .page_title {
  font-size: 1.8em;
  line-height: 1.45em;
  a {
    text-decoration: none;
  }
  &.linkpost_title {
    font-size: 1.17em;
    line-height: 1.35em;
    padding-top: 12px;
    a {
      text-decoration: underline;
      &:hover {
        text-decoration: none;
      }
    }
    &::after {
      content: "\a0→";
      color: $accent-grey;
    }
  }
  a:visited {
    color: $primary-color;
  }
  margin-bottom: -10px;
}

.continue_reading {
  font-weight: bold;
  &::after {
    content: "\a0→";
  }
}

.post_meta {
  margin-top: -10px;
  &, a, a:visited {
    color: $accent-grey;
  }
  font-size: $meta-font-size;
  .post_permalink a {
    &, &:visited {
      color: $primary-color;
    }
    text-decoration: none;
  }
}
