{% extends "base.html" %}

{% block content %}

<article>

{% if title %}
  <h1 class="article_title" style="margin-bottom: -5px;">{{ title }}</h1>
{% endif %}

{% for year, posts in post_groups %}
  <h2>{{ year }}</h2>
  <ul>
    {% for post in posts %}
    <li>
      <div class="archive_date">{{ post.metadata['date'].strftime('%b %-d') }}</div> <a href="/{{ post.metadata.url }}">{{ post.metadata.title|title|safe }}</a>
    </li>
    {% endfor %}
  </ul>
{% endfor %}

</article>

{% endblock %}
