// https://en.wikipedia.org/wiki/Chocolate_(color)
$primary-color: #7B3F00 !default;
$primary-dark: #59260B !default;

$main-font-family:  serif !default;
$mono-font:         Menlo, Consolas, monospace;

$black:           #202020;
$accent-grey:     #999;
$light-grey:      #eee;
$midtone-gray:    #ccc;

$max-width:       750px !default;
$line-height:     1.4em !default;
$default-padding: 20px !default;
$meta-font-size:  0.85em !default;
$big-font-size:   2em !default;

#aside_inner, #footer_inner, article,
#subtitle,
#pagination {
  max-width: $max-width;
  margin-left:  auto;
  margin-right: auto;
  padding: 1px 20px;
}

@import "aside.scss";
@import "footer.scss";
@import "code.scss";
@import "article.scss";
@import "pagination.scss";


a {
  color: $primary-color;
  &:hover {
    text-decoration: none;
  }
  &:visited {
    color: $primary-dark;
  }
}

h1 {
  color: $primary-color;
}

h2 {
  line-height: $line-height;
  padding-top: $default-padding / 2;
}

body {
  font: 12pt $main-font-family;
  line-height: $line-height;
  color: $black;
}

hr {
  background-color: $light-grey;
  height: 1px;
  border: 0px;
}

blockquote {
//  color: $primary-dark;
  border-left: 5px solid $midtone-gray;
  background-color: $light-grey;
//  border-left: 5px solid rgba(red($primary-color), green($primary-color), blue($primary-color), 0.8);
//  background-color: rgba(red($primary-color), green($primary-color), blue($primary-color), 0.1);
  margin-left:  0px;
  margin-right: 0px;
  padding: 1px $default-padding * 0.75;
//  color: $primary-color;
//  font-style: italic;
  font-size: 0.95em;
  code, pre {
    background-color: #ddd;
  }
  pre {
    border-color: #aaa;
  }
  line-height: $line-height * 0.95;
}

// Images never expand beyond the article bounds, and are centred when
// they're too small.
img, video {
  max-width: 100%;
  margin-left:  auto;
  margin-right: auto;
  display: block;
}

.footnote {
  font-size: 1em * $scaling-factor;
  line-height: $line-height * $scaling-factor;
}

// These rules help with the positioning of footnote markers, although
// I'm not entirely sure how they work.
sup, sub {
  vertical-align: 0ex;
  position: relative;
}

sub {
  top: 0.8ex;
}

sup {
  bottom: 1ex;
}

.index_title {
  margin-bottom: 0px;
}
